@@ -29,7 +29,7 @@ require RPC::PlServer::Comm;
 package RPC::PlServer;
 
 @RPC::PlServer::ISA = qw(Net::Daemon RPC::PlServer::Comm);
-$RPC::PlServer::VERSION = '0.2001';
+$RPC::PlServer::VERSION = '0.2003';
 
 
 ############################################################################
@@ -252,6 +252,9 @@ sub DestroyHandle ($$) {
 sub CallMethod ($$$@) {
     my($self, $handle, $method, @args) = @_;
     my($ref, $object);
+
+    my $lock = lock($Net::Daemon::RegExpLock)
+	if $Net::Daemon::RegExpLock && $self->{'mode'} eq 'threads';
     if ($handle =~ /=\w+\(0x/) {
 	# Looks like a call by instance
 	$object = $self->UseHandle($handle);
